@@ -1,4 +1,4 @@
-/* $Id: book.h 1350 2006-08-04 16:53:56Z holger $
+/* $Id: book.h 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/book.h
  *
@@ -94,10 +94,17 @@ class BookHeader {
 	static BookHeader b2h(const BookHeader& b, bool swap_byteorder);
 };
 
-class BookException : public std::runtime_error {
+class BookException {
+	std::string msg; 
+
       public:
-	BookException() : std::runtime_error("BookException")
+	BookException(const std::string& msg) : msg(msg)
 	{}
+
+      public:
+	const std::string& get_msg() {
+		return msg;
+	}
 };
 
 
