@@ -1,4 +1,4 @@
-/* $Id: board_util.cc 1350 2006-08-04 16:53:56Z holger $
+/* $Id: board_util.cc 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/board_util.cc
  *
@@ -109,14 +109,21 @@ void Board::print(FILE * fp, Move last_move) const
 			if (ansicolor && fp == stdout) {
 				const char * a1 = (i+j)%2
 					? "\033[47m" : "\033[40m";
-				const char * a2 = color_at(sq) == WHITE
-					? "\033[31;1m" : "\033[34;1m";
 
+				const char * a2 = "";
 				const char * a3 = "";
-				if (last_move) {
-					if (sq == last_move.from()
-							|| sq == last_move.to())
-						a3 = "\033[7m";
+				if (last_move && (sq == last_move.from() 
+						|| sq == last_move.to())) {
+					a2 = XSIDE(side) == WHITE
+						? "\033[31;1m"
+						: "\033[34;1m";
+					a3 = "\033[7m";
+				} else {
+					if (color_at(sq) == WHITE) {
+						a2 = "\033[31;1m";
+					} else if (color_at(sq) == BLACK) {
+						a2 = "\033[34;1m";
+					}
 				}
 
 				const char * a4 = "\033[0m";
@@ -148,7 +155,7 @@ void Board::print_small(FILE * fp) const
 	for (int i=7; i>=0; i--) {
 		//fprintf(fp, "%d ", i+1);
 		for (int j=0; j<=7; j++) {
-			sq = i*8 + j;
+			sq = SQUARE(i,j);
 			if (piece_at(sq) != NO_PIECE) {
 				c = piece_char[piece_at(sq)];
 				if (color_at(sq) == WHITE)
