@@ -1,4 +1,4 @@
-/* $Id: eval.cc 1395 2006-10-29 12:44:00Z holger $
+/* $Id: eval.cc 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/chess/eval.cc
  *
@@ -151,7 +151,7 @@ const struct score_plugin Evaluator::plugins[] = {
 	{ "knights",	&Evaluator::score_knights	},
 	{ "bishops",	&Evaluator::score_bishops	},
 	{ "rooks",	&Evaluator::score_rooks		},
-//	{ "queens",	&Evaluator::score_queens	},
+	{ "queens",	&Evaluator::score_queens	},
 	{ "king",	&Evaluator::score_king		},
 	{ "devel",	&Evaluator::score_devel		},
 	{ "combo",	&Evaluator::score_combo		},
@@ -444,6 +444,7 @@ int Evaluator::score_bishops(Color side)
  * Rook evaluation.
  */
 
+#define EVAL_ROOKMOBILITY	2
 #define EVAL_ROOKOPENFILE	10
 #define EVAL_ROOKHALFOPENFILE	5
 #define EVAL_ROOK7PAWNS7	20	// FIXME too high?
@@ -466,6 +467,13 @@ int Evaluator::score_rooks(Color side)
 		sq = rooks.firstbit();
 		rooks.clearbit(sq);
 
+#ifdef EVAL_ROOKMOBILITY
+		/* Simple mobility bonus */
+		Bitboard ra = board->rook_attacks(sq)
+				& ~board->get_pieces(side);
+		score += ra.popcnt() * EVAL_ROOKMOBILITY;
+#endif
+		
 #if defined(EVAL_ROOKOPENFILE) && defined(EVAL_ROOKHALFOPENFILE)
 		/* Rook on open/half-open file */
 		if (! (Bitboard::file[FIL(sq)] & board->get_pawns(side)) ) {
@@ -539,6 +547,7 @@ int Evaluator::score_rooks(Color side)
  */
 
 //#define EVAL_QUEENNOTPRESENT	-40
+#define EVAL_QUEENMOBILITY	1
 //#define EVAL_QUEENNEARENEMYKING	5
 //#define EVAL_PINNEDQUEEN	-90
 
@@ -560,6 +569,13 @@ int Evaluator::score_queens(Color side)
 		sq = queens.firstbit();
 		queens.clearbit(sq);
 		
+#ifdef EVAL_QUEENMOBILITY
+		/* Simple mobility bonus */
+		Bitboard qa = board->queen_attacks(sq)
+				& ~board->get_pieces(side);
+		score += qa.popcnt() * EVAL_QUEENMOBILITY;
+#endif
+		
 #ifdef EVAL_PINNEDQUEEN
 		/* Pinned queen? */
 		if (pinned_on_king[side].testbit(sq)) {
@@ -570,7 +586,7 @@ int Evaluator::score_queens(Color side)
 #ifdef EVAL_QUEENNEARENEMYKING
 		/* Queen near enemy king */
 		Square xking = board->get_king(XSIDE(side));
-		unsigned int dist = sq_distance[sq][xking];
+		unsigned int dist = sq_distance(sq, xking);
 		if (dist < 5) {
 			score += dist * EVAL_QUEENNEARENEMYKING;
 		}
