@@ -1,4 +1,4 @@
-/* $Id: compile.h 1270 2006-07-16 19:46:57Z holger $
+/* $Id: compile.h 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/compile.h
  *
@@ -26,11 +26,24 @@
 #define COMPILE_DATE	__DATE__ " " __TIME__
 
 #if defined(__GNUC__)
-# define COMPILER	"GCC " __VERSION__
+# define COMPILER		"GCC"
+# define COMPILER_VERSION	 __VERSION__
 #elif defined(__INTEL_COMPILER)
-# define COMPILER	"ICC"
+# define COMPILER		"ICC"
+# define COMPILER_VERSION	"unknown"
 #else
-# define COMPILER	"unknown"
+# define COMPILER		"unknown"
+# define COMPILER_VERSION	"unknown"
 #endif
 
+#if defined(__unix__)
+# define PLATFORM		"unix"
+#elif defined(WIN32) && defined(__MINGW32__)
+# define PLATFORM		"mingw32"
+#elif defined(WIN32)
+# define PLATFORM		"win32"
+#else
+# define PLATFORM		"unknown"
+#endif	
+
 #endif /* COMPILE_H */
