@@ -1,4 +1,4 @@
-/* $Id: config.h 1256 2006-06-28 16:55:13Z holger $
+/* $Id: config.h 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/config.h
  *
@@ -67,6 +67,10 @@
 /* Use evaluation cache */
 #define USE_EVALCACHE
 
+/* Search extensions */
+#define EXTEND_IN_CHECK
+#define EXTEND_RECAPTURE
+
 /* Maximum depth for full-width search */
 #define MAXDEPTH		900
 
