@@ -1,8 +1,8 @@
-/* $Id: init.cc 1350 2006-08-04 16:53:56Z holger $
+/* $Id: init.cc 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/init.cc
  *
- * Copyright (C) 2004, 2005 Holger Ruckdeschel <holger@hoicher.de>
+ * Copyright (C) 2004-2007 Holger Ruckdeschel <holger@hoicher.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,18 +28,6 @@
 #include <time.h>
 
 
-void init_sq_distance()
-{
-	for (unsigned int f=0; f<BOARDSIZE; f++) {
-		for (unsigned int t=0; t<BOARDSIZE; t++) {
-			int rd = abs(RNK(t)-RNK(f));
-			int fd = abs(FIL(t)-FIL(f));
-			sq_distance[f][t] = MAX(rd, fd); 
-		}
-	}
-
-}
-
 /*****************************************************************************
  * 
  * This is the main initialization function.
@@ -49,7 +37,7 @@ void init_sq_distance()
 
 void init()
 {
-	init_sq_distance();
+	basic_init();
 #ifdef HOICHESS
 	Bitboard::init();
 #endif
