@@ -1,4 +1,4 @@
-/* $Id: main.cc 1377 2006-09-17 11:49:11Z holger $
+/* $Id: main.cc 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/main.cc
  *
@@ -21,6 +21,7 @@
  *
  */
 
+#include <errno.h>
 #include <getopt.h>
 #ifndef WIN32
 # include <signal.h>
@@ -56,25 +57,26 @@ static void sigint_handler(int sig)
 extern void init();
 extern void fini();
 
-static void print_version(bool verbose = false)
+static void print_version()
 {
-	if (verbose) {
-		printf("%s %s (%s, %s)\n", PROGNAME, VERSION,
-				COMPILE_DATE, COMPILER);
-	} else {
-		printf("%s %s\n", PROGNAME, VERSION);
-	}
+	printf("%s %s (%s)\n", PROGNAME, VERSION, COMPILE_DATE);
 }
 
 static void print_copyright()
 {
 	printf(
-"Copyright (C) 2004-2006 %s %s\n"
+"Copyright (C) 2004-2007 %s %s\n"
 "This program is free software and comes with ABSOLUTELY NO WARRANTY.\n"
 "See the GNU General Public License for more details.\n",
 			AUTHOR, AUTHOR_EMAIL);
 }
 
+static void print_info()
+{
+	printf("Platform: %s\n", PLATFORM);
+	printf("Compiler: %s %s\n", COMPILER, COMPILER_VERSION);
+}
+
 static void usage(const char * argv0)
 {
 	print_version();
@@ -95,7 +97,7 @@ static void usage(const char * argv0)
 #ifdef USE_EVALCACHE
 	printf("       --evalcache SIZE	Set size of evaluation cache (default: %s)\n", DEFAULT_EVALCACHESIZE);
 #endif
-	printf("       --script FILE    Read initial commands from FILE\n");
+	printf("       --rcfile FILE    Read initial commands from FILE\n");
 
 	printf(
 "\nThese are only the most general options. See documentation for a complete\n"
@@ -107,15 +109,15 @@ static void usage(const char * argv0)
 
 int main(int argc, char ** argv)
 {
-	char * opt_logfile = NULL;
-	char * opt_xboard = "auto";
-	char * opt_hashsize = DEFAULT_HASHSIZE;
-	char * opt_bookfile = DEFAULT_BOOK;
-	char * opt_name = NULL;
-	char * opt_scriptfile = NULL;
-	char * opt_color = "auto";
-	char * opt_evalcache = DEFAULT_EVALCACHESIZE;
-	char * opt_pawnhashsize = DEFAULT_PAWNHASHSIZE;
+	const char * opt_logfile = NULL;
+	const char * opt_xboard = "auto";
+	const char * opt_hashsize = DEFAULT_HASHSIZE;
+	const char * opt_bookfile = DEFAULT_BOOK;
+	const char * opt_name = NULL;
+	const char * opt_rcfile = NULL;
+	const char * opt_color = "auto";
+	const char * opt_evalcache = DEFAULT_EVALCACHESIZE;
+	const char * opt_pawnhashsize = DEFAULT_PAWNHASHSIZE;
 
 	/* Most Unix platforms have color terminals. But on Win32 systems,
 	 * ANSI color is normally not available. */
@@ -142,7 +144,8 @@ int main(int argc, char ** argv)
 		{ "book", 1, 0, 129 },
 		{ "nobook", 0, 0, 130 },
 		{ "name", 1, 0, 131 },
-		{ "script", 1, 0, 132 },
+		{ "rcfile", 1, 0, 132 },
+		{ "script", 1, 0, 240 },		// deprecated
 		{ "color", 1, 0, 133 },
 		{ "evalcache", 1, 0, 134 },
 		{ "pawnhashsize", 1, 0, 135 },
@@ -195,8 +198,13 @@ int main(int argc, char ** argv)
 		case 131: /* --name */
 			opt_name = optarg;
 			break;
-		case 132: /* --script */
-			opt_scriptfile = optarg;
+		case 132: /* --rcfile */
+			opt_rcfile = optarg;
+			break;
+		case 240: /* --script (deprecated) */
+			opt_rcfile = optarg;
+			printf("Warning: option --script is deprecated."
+					" Use --rcfile.\n");
 			break;
 		case 133: /* --color */
 			opt_color = optarg;
@@ -217,9 +225,11 @@ int main(int argc, char ** argv)
 	}
 
 	
-	print_version(true);
+	print_version();
 	print_copyright();
 	printf("\n");
+	print_info();
+	printf("\n");
 
 	if (debug) {
 		debug_print_compiletime_config();
@@ -296,10 +306,14 @@ int main(int argc, char ** argv)
 	 */
 
 	init();
-
 	shell = new Shell();
+	shell->set_myname(opt_name);
+	shell->set_xboard(xboard_mode);
+
+	/* opening book */
 	shell->set_book(opt_bookfile);
 	
+	/* main hash size */
 	if (opt_hashsize) {
 		long size = 0;
 		if (!parse_size(opt_hashsize, &size) || size < 0) {
@@ -311,6 +325,7 @@ int main(int argc, char ** argv)
 		shell->set_hashsize(size);
 	}
 	
+	/* pawh hash size */
 	if (opt_pawnhashsize) {
 		long size = 0;
 		if (!parse_size(opt_pawnhashsize, &size) || size < 0) {
@@ -323,6 +338,7 @@ int main(int argc, char ** argv)
 	}
 
 #ifdef USE_EVALCACHE
+	/* evalation cache size */
 	if (opt_evalcache) {
 		long size = 0;
 		if (!parse_size(opt_evalcache, &size) || size < 0) {
@@ -335,10 +351,31 @@ int main(int argc, char ** argv)
 		shell->set_evalcachesize(size);
 	}
 #endif
+
+	/* read script file if given on command line */
+	if (opt_rcfile) {
+		FILE * fp = fopen(opt_rcfile, "r");
+		if (fp == NULL) {
+			fprintf(stderr, "Cannot open %s for reading: %s\n",
+					opt_rcfile, strerror(errno));
+			exit(EXIT_FAILURE);
+		}
+		shell->source_file(fp, opt_rcfile);
+	}
 	
-	shell->set_myname(opt_name);
-	shell->include_script(opt_scriptfile);
-	shell->set_xboard(xboard_mode);
+	/* read hoichess.rc; note that commands here are executed _before_
+	 * commands in --script file, because the last opened source is
+	 * read at as first... */
+#if defined(HOICHESS)
+	const char * rcfile = "hoichess.rc";
+#elif defined(HOIXIANGQI)
+	const char * rcfile = "hoixiangqi.rc";
+#endif
+	FILE * fp = fopen(rcfile, "r");
+	if (fp != NULL) {
+		shell->source_file(fp, rcfile);
+	}
+
 #ifndef WIN32
 	signal(SIGINT, sigint_handler);	
 #endif 
