@@ -1,4 +1,4 @@
-/* $Id: search.cc 1381 2006-10-01 07:59:06Z holger $
+/* $Id: search.cc 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/search.cc
  *
@@ -89,6 +89,7 @@ void Search::start(Game _game, int _mode, Color _myside)
 	start_mutex.lock();
 	DBG(2, "locked start_mutex");
 
+	ASSERT(!thread);
 	ASSERT(game == NULL);
 	game = &_game;
 	mode = _mode;
@@ -261,9 +262,6 @@ void Search::main()
 
 	if (verbose || showthinking && !shell->xboard) {
 		print_statistics();
-	}
-
-	if (verbose) {
 		update_overall_statistics();
 		print_overall_statistics();
 	}
@@ -291,6 +289,9 @@ void Search::iterate()
 	int beta = INFTY;
 	
 	for (rootdepth = 1; rootdepth <= maxdepth; rootdepth++) {
+		maxplyreached = 0;
+		maxplyreached_quiesce = 0;
+
 		/* Search the root node. */
 		score = search_root(0, rootdepth, alpha, beta);
 		if (stop) {
@@ -383,18 +384,19 @@ int Search::search_root(unsigned int ply, int depth, int alpha, int beta)
 		/* Search the current move. We use a standard
 		 * principal variation search here. */
 		if (first) {
-			score = -search(ply+1, depth-1, -beta, -alpha);
+			score = -search(ply+1, depth-1, 0, -beta, -alpha);
 			first = false;
 		} else {
-			score = -search(ply+1, depth-1, -alpha-1, -alpha);
+			score = -search(ply+1, depth-1, 0, -alpha-1, -alpha);
 			if (score > alpha && score < beta) {
-				score = -search(ply+1, depth-1, -beta, -alpha);
+				score = -search(ply+1, depth-1, 0, 
+						-beta, -alpha);
 			}			
 		}
 #else
 		/* Search the current move. We use a pure
 		 * alpha-beta search here. */
-		score = -search(ply+1, depth-1, -beta, -alpha);
+		score = -search(ply+1, depth-1, 0, -beta, -alpha);
 #endif
 
 		tree.unmake_move();
@@ -436,7 +438,7 @@ int Search::search_root(unsigned int ply, int depth, int alpha, int beta)
 	return alpha;
 }
 
-int Search::search(unsigned int ply, int depth, int alpha, int beta)
+int Search::search(unsigned int ply, int depth, int extend, int alpha, int beta)
 {
 	ASSERT_DEBUG(tree.get_current_ply() == ply);
 	Node * node = tree[ply];
@@ -459,6 +461,10 @@ int Search::search(unsigned int ply, int depth, int alpha, int beta)
 	
 	nodes++;
 	
+	if (ply > maxplyreached) {
+		maxplyreached = ply;
+	}
+
 	/*
 	 * First look into the hash table if this
 	 * position has already been search before.
@@ -500,7 +506,7 @@ int Search::search(unsigned int ply, int depth, int alpha, int beta)
 				   == Evaluator::ENDGAME);
 	if (!node->in_check() && null_ok) {
 		tree.make_move(Move::null());
-		score = -search(ply+1, depth-2-1, -beta, -beta+1);
+		score = -search(ply+1, depth-2-1, 0, -beta, -beta+1);
 		tree.unmake_move();
 		if (score >= beta) {
 			STAT_INC(stat_nullcut);
@@ -519,7 +525,7 @@ int Search::search(unsigned int ply, int depth, int alpha, int beta)
 	 * to search first.
 	 */
 	if (!node->get_hashmv() && depth > 2) {
-		search(ply, depth-2, alpha, beta);
+		search(ply, depth-2, 0, alpha, beta);
 		node->set_hashmv(node->get_best());
 	}
 #endif
@@ -552,7 +558,32 @@ int Search::search(unsigned int ply, int depth, int alpha, int beta)
 	}
 #endif // USE_FUTILITYPRUNING
 
-	
+	/*
+	 * Search extensions.
+	 */
+	if (extend == 0) {
+#ifdef EXTEND_IN_CHECK
+		if (node->in_check()) {
+			extend++;
+		}
+#endif
+#ifdef EXTEND_RECAPTURE
+		if (ply >= 3) {
+			int mb = node->material_balance();
+			int mb1 = -tree[ply-1]->material_balance();
+			int mb2 = tree[ply-2]->material_balance();
+			int mb3 = -tree[ply-3]->material_balance();
+			if (abs(mb - mb1) >= 900 && abs(mb - mb2) >= 900
+					&& abs(mb - mb3) >= 900) {
+				extend++;
+			}
+		}
+#endif
+	} else {
+		depth += extend;
+		extend = 0;
+	}
+
 	/*
 	 * Search all successor moves.
 	 */
@@ -583,18 +614,20 @@ int Search::search(unsigned int ply, int depth, int alpha, int beta)
 		/* Search the current move. We use a standard
 		 * principal variation search here. */
 		if (first) {
-			score = -search(ply+1, depth-1, -beta, -alpha);
+			score = -search(ply+1, depth-1, extend, -beta, -alpha);
 			first = false;
 		} else {
-			score = -search(ply+1, depth-1, -alpha-1, -alpha);
+			score = -search(ply+1, depth-1, extend,
+					-alpha-1, -alpha);
 			if (score > alpha && score < beta) {
-				score = -search(ply+1, depth-1, -beta, -alpha);
+				score = -search(ply+1, depth-1, extend,
+						-beta, -alpha);
 			}			
 		}
 #else
 		/* Search the current move. We use a pure
 		 * alpha-beta search here. */
-		score = -search(ply+1, depth-1, -beta, -alpha);
+		score = -search(ply+1, depth-1, extend, -beta, -alpha);
 #endif
 
 		tree.unmake_move();
@@ -688,6 +721,10 @@ int Search::quiescence_search(unsigned int ply, int alpha, int beta)
 	
 	nodes_quiesce++;
 
+	if (ply > maxplyreached_quiesce) {
+		maxplyreached_quiesce = ply;
+	}
+
 	/*
 	 * First look into the hash table if this
 	 * position has already been search before.
