@@ -1,4 +1,4 @@
-/* $Id: shell.h 1350 2006-08-04 16:53:56Z holger $
+/* $Id: shell.h 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/shell.h
  *
@@ -41,6 +41,13 @@ class Search;
 
 class Shell
 {
+      private:
+	typedef struct {
+		std::string name;
+		unsigned int line;
+		FILE * fp;
+	} source_t;
+	
       public:
 	/* Public, because also accessed from Search. */
 	bool xboard;
@@ -52,8 +59,8 @@ class Shell
 	bool flag_analyze;
 	bool flag_playboth;
 	
-	std::list<std::string> script_lines;
-	std::list<std::string>::iterator script_it;
+	source_t source;
+	std::list<source_t> sources;
 
 	std::string myname;
 	
@@ -78,7 +85,7 @@ class Shell
 	~Shell();
 
       public:
-	void main();
+	void main(const char * filename = NULL);
 	void interrupt();
 
       public:
@@ -87,13 +94,14 @@ class Shell
 	void set_pawnhashsize(unsigned long size);
 	void set_evalcachesize(unsigned long size);
 	void set_myname(const char * name);
-	void include_script(const char * scriptfile);
 	void set_xboard(bool x);
-	
+
+      public:
+	void source_file(FILE * fp, const char * name);
       private:
 	void input();
-	char * get_line_script();
-	char * get_line_fgets(const char * prompt);
+	char * get_line(const char * prompt);
+	char * get_line_fgets(FILE * fp, const char * prompt);	
 #ifdef HAVE_READLINE
 	char * get_line_readline(const char * prompt);
 #endif
@@ -118,6 +126,7 @@ class Shell
 	void cmd_accepted();
 	void cmd_rejected();
 	void cmd_new();
+	void cmd_variant();
 	void cmd_quit();
 	void cmd_force();
 	void cmd_go();
@@ -143,7 +152,7 @@ class Shell
 	void cmd_ignore();
 	void cmd_obey();
 	void cmd_help();
-	void cmd_script();
+	void cmd_source();
 	void cmd_echo();
 	void cmd_show();
 	void cmd_solve();
