@@ -1,4 +1,4 @@
-/* $Id: shell_cmd.cc 1379 2006-09-17 12:36:47Z holger $
+/* $Id: shell_cmd.cc 1452 2007-10-30 16:11:59Z holger $
  *
  * HoiChess/shell_cmd.cc
  *
@@ -38,7 +38,7 @@ struct Shell::command Shell::commands[] = {
 	{ "accepted",	&Shell::cmd_accepted,	false,	""	},
 	{ "rejected",	&Shell::cmd_rejected,	false,	""	},
 	{ "new",	&Shell::cmd_new,	false,	"Start a new game" },
-	{ "variant",	NULL,			false,	""	},
+	{ "variant",	&Shell::cmd_variant,	false,  ""	},
 	{ "quit",	&Shell::cmd_quit,	false,	"Quit" },
 	{ "random",	NULL,			true,	""	},
 	{ "force",	&Shell::cmd_force,	false,	"Let engine make no moves at all" },
@@ -82,7 +82,7 @@ struct Shell::command Shell::commands[] = {
 	{ "ignore",	&Shell::cmd_ignore,	false,	""	},
 	{ "obey",	&Shell::cmd_obey,	false,  ""	},
 	{ "help",	&Shell::cmd_help,	false,	""	},
-	{ "script",	&Shell::cmd_script,	false,	""	},
+	{ "source",	&Shell::cmd_source,	false,	""	},
 	{ "echo",	&Shell::cmd_echo,	false,	""	},
 	{ "show",	&Shell::cmd_show,	false,	""	},
 	{ "solve",	&Shell::cmd_solve,	false,	""	},
@@ -124,13 +124,23 @@ void Shell::cmd_protover()
 	std::ostringstream ss;
 	ss << "feature";
 	ss << " myname=\"" << myname << "\"";
+
+#if defined(HOICHESS)
 	ss << " variants=\"normal\"";
+#elif defined(HOIXIANGQI)
+	ss << " variants=\"xiangqi\"";
+#else
+# error "neither HOICHESS nor HOIXIANGQI defined"
+#endif
+	
 	ss << " ping=1 setboard=1 time=1 sigint=0 colors=0";
+
 #if defined(HAVE_PTHREAD) || defined(WIN32)
 	ss << " analyze=1";
 #else
 	ss << " analyze=0";
 #endif
+
 	ss << " name=1";
 	ss << " done=1\n";
 
@@ -166,6 +176,26 @@ void Shell::cmd_new()
 	}
 }
 
+void Shell::cmd_variant()
+{
+	CMD_REQUIRE_ARGS(1);
+
+	const std::string& v = cmd_args[1];
+
+#if defined(HOICHESS)
+	if (0) {
+		/* for standard chess, the 'variant' command is never sent */
+#elif defined(HOIXIANGQI)
+	if (v == "xiangqi") {
+		/* used by Winboard_F by H.G. Muller */
+#else
+# error "neither HOICHESS nor HOIXIANGQI defined"
+#endif
+	} else {
+		printf("Error (variant not supported): %s\n", v.c_str());
+	}
+}
+
 void Shell::cmd_quit()
 {
 	quit = true;
@@ -175,6 +205,7 @@ void Shell::cmd_force()
 {
 	search->stop_thread();
 	flag_force = true;
+	flag_playboth = false;
 	myside = NO_COLOR;
 }
 
@@ -182,6 +213,7 @@ void Shell::cmd_go()
 {
 	search->stop_thread();
 	flag_force = false;
+	flag_playboth = false;
 	myside = game->get_side();
 }
 
@@ -461,11 +493,19 @@ void Shell::cmd_help()
 	}
 }
 
-void Shell::cmd_script()
+void Shell::cmd_source()
 {
 	CMD_REQUIRE_ARGS(1);
 	const char * filename = cmd_args[1].c_str();
-	include_script(filename);
+
+	FILE * fp = fopen(filename, "r");
+	if (fp == NULL) {
+		fprintf(stderr, "Cannot open %s for reading: %s\n",
+				filename, strerror(errno));
+		exit(EXIT_FAILURE);
+	}
+
+	source_file(fp, filename);
 }
 
 void Shell::cmd_echo()
@@ -600,6 +640,14 @@ void Shell::cmd_solve()
 			printf("Clearing hash table.\n");
 			hashtable->clear();
 		}
+		if (pawnhashtable) {
+			printf("Clearing pawn hash table.\n");
+			pawnhashtable->clear();
+		}
+		if (evalcache) {
+			printf("Clearing evaluation cache.\n");
+			evalcache->clear();
+		}
 		printf("Thinking...\n");
 		search->start(board, game->get_clock(), Search::MOVE);
 
@@ -903,7 +951,9 @@ void Shell::cmd_get()
 
 void Shell::cmd_playboth()
 {
-	flag_playboth = !flag_playboth;
+	search->stop_thread();
+	flag_playboth = true;
+	flag_force = false;
 }
 
 void Shell::cmd_loadgame()
